@@ -16,12 +16,10 @@ class WrapperData:
     type: str
     data: Dict
 
-
 @dataclass
-class DatasetInfo:
+class InputInfo:
     name: str
-    dataset_version: Dict
-
+    shape: List[int]
 
 @dataclass
 class NodeResponse:
